@@ -221,9 +221,9 @@ class IndexView(BaseView):
 class SimpleFormView(BaseView):
     """
         View for presenting your own forms
-        Inherit from this view to provide some base processing for your costumized form views.
+        Inherit from this view to provide some base processing for your customized form views.
 
-        Notice that this class inherits from BaseView so all properties from the parent class can be overrided also.
+        Notice that this class inherits from BaseView so all properties from the parent class can be overridden also.
 
         Implement form_get and form_post to implement your form pre-processing and post-processing
     """
@@ -231,17 +231,31 @@ class SimpleFormView(BaseView):
     form_template = 'appbuilder/general/model/edit.html'
     
     edit_widget = FormWidget
-    form_title = 'Form Title'
+    form_title = ''
     """ The form title to be displayed """
     form_columns = []
-    """ The form columns to include """
+    """ The form columns to include, if empty will include all"""
     form = None
     """ The WTF form to render """
+    form_fieldsets = []
+    
+    def _init_vars(self):
+        list_cols = [field.name for field in self.form.refresh()]
+        if self.form_fieldsets:
+            self.form_columns = []
+            for fieldset_item in self.form_fieldsets:
+                self.form_columns = self.form_columns + list(fieldset_item[1].get('fields'))
+        else:
+            if not self.form_columns:
+                self.form_columns = list_cols
+        
     
     @expose("/form", methods=['GET'])
     @has_access
     def this_form_get(self):
+        self._init_vars()
         form = self.form.refresh()
+        
         self.form_get(form)
         widgets = self._get_edit_widget(form = form)
         return render_template(self.form_template,
@@ -259,7 +273,9 @@ class SimpleFormView(BaseView):
     @expose("/form", methods=['POST'])
     @has_access
     def this_form_post(self):
+        self._init_vars()
         form = self.form.refresh()
+        
         if form.validate_on_submit():
             self.form_post(form)
             return redirect(self._get_redirect())
@@ -281,8 +297,10 @@ class SimpleFormView(BaseView):
     def _get_edit_widget(self, form = None, exclude_cols = [], widgets = {}):
         widgets['edit'] = self.edit_widget(route_base = self.route_base,
                                                 form = form,
+                                                include_cols = self.form_columns,
                                                 exclude_cols = exclude_cols,
-                                                )
+                                                fieldsets = self.form_fieldsets
+                                                )         
         return widgets
 
 
